@@ -11,5 +11,5 @@ use rocket::State;
 use crate::ConfigState;
 
 pub fn build_path(id: &str, config: &State<ConfigState>) -> std::path::PathBuf {
-    std::path::Path::new(&config.storage_dir).join(&id)
+    std::path::Path::new(&config.app_config.storage_dir).join(&id)
 }
